@@ -1,22 +1,17 @@
-/*************************************************************************
- *  Copyright (C) 2008,2009 by Volker Lanz <vl@fidra.de>                 *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2008 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2012-2017 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015 Chris Campbell <c.j.campbell@ed.ac.uk>
+    SPDX-FileCopyrightText: 2016 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2016 Chantara Tith <tith.chantara@gmail.com>
+    SPDX-FileCopyrightText: 2020 Arnaud Ferraris <arnaud.ferraris@collabora.com>
+    SPDX-FileCopyrightText: 2020 Gaël PORTAY <gael.portay@collabora.com>
 
-#if !defined(KPMCORE_LINUXSWAP_H)
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
+#ifndef KPMCORE_LINUXSWAP_H
 #define KPMCORE_LINUXSWAP_H
 
 #include "util/libpartitionmanagerexport.h"
@@ -37,7 +32,7 @@ namespace FS
 class LIBKPMCORE_EXPORT linuxswap : public FileSystem
 {
 public:
-    linuxswap(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);
+    linuxswap(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QVariantMap& features = {});
 
 public:
     void init() override;
@@ -45,7 +40,6 @@ public:
     bool create(Report& report, const QString& deviceNode) override;
     bool resize(Report& report, const QString& deviceNode, qint64 length) const override;
     bool writeLabel(Report& report, const QString& deviceNode, const QString& newLabel) override;
-    bool writeLabelOnline(Report& report, const QString& deviceNode, const QString& mountPoint, const QString& newLabel) override;
     bool copy(Report& report, const QString& targetDeviceNode, const QString& sourceDeviceNode) const override;
     bool updateUUID(Report& report, const QString& deviceNode) const override;
     qint64 readUsedCapacity(const QString& deviceNode) const override;
@@ -81,9 +75,6 @@ public:
     CommandSupportType supportSetLabel() const override {
         return m_SetLabel;
     }
-    CommandSupportType supportSetLabelOnline() const override {
-        return m_SetLabel;
-    }
     CommandSupportType supportUpdateUUID() const override {
         return m_UpdateUUID;
     }
